// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KNOTIFICATIONS_VERSION_H
#define KNOTIFICATIONS_VERSION_H

#define KNOTIFICATIONS_VERSION_STRING "6.16.0"
#define KNOTIFICATIONS_VERSION_MAJOR 6
#define KNOTIFICATIONS_VERSION_MINOR 16
#define KNOTIFICATIONS_VERSION_PATCH 0
#define KNOTIFICATIONS_VERSION ((6<<16)|(16<<8)|(0))

#endif
